@@ -1,9 +1,9 @@
 package Acme::CPANModules::GrepVariants;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-07-02'; # DATE
+our $DATE = '2021-07-05'; # DATE
 our $DIST = 'Acme-CPANModules-GrepVariants'; # DIST
-our $VERSION = '0.005'; # VERSION
+our $VERSION = '0.006'; # VERSION
 
 use strict;
 use Acme::CPANModulesUtil::Misc;
@@ -117,6 +117,9 @@ rows of CSV.
 
 <prog:jgrep> from <pm:App::JsonLogUtils>
 
+<prog:pdfgrep> (alias: <prog:grep-from-pdf>) from <pm:App::PDFUtils> searches
+against text in PDF files (it's a wrapper for `pdftotext` utility and grep).
+
 <prog:ptargrep> from <pm:Archive::Tar> searches against table of contents of tar
 files.
 
@@ -161,7 +164,7 @@ Acme::CPANModules::GrepVariants - Grep-like CLI utilities available on CPAN
 
 =head1 VERSION
 
-This document describes version 0.005 of Acme::CPANModules::GrepVariants (from Perl distribution Acme-CPANModules-GrepVariants), released on 2021-07-02.
+This document describes version 0.006 of Acme::CPANModules::GrepVariants (from Perl distribution Acme-CPANModules-GrepVariants), released on 2021-07-05.
 
 =head1 DESCRIPTION
 
@@ -266,6 +269,9 @@ L<grep-from-exchange> from L<App::CryptoCurrencyUtils>.
 
 L<jgrep> from L<App::JsonLogUtils>
 
+L<pdfgrep> (alias: L<grep-from-pdf>) from L<App::PDFUtils> searches
+against text in PDF files (it's a wrapper for C<pdftotext> utility and grep).
+
 L<ptargrep> from L<Archive::Tar> searches against table of contents of tar
 files.
 
@@ -328,6 +334,8 @@ L<dategrep> from L<App::dategrep> prints lines matching a date range.
 
 =item * L<App::JsonLogUtils>
 
+=item * L<App::PDFUtils>
+
 =item * L<Archive::Tar>
 
 =item * L<App::grep::url>
